% script mls_array_model_int
% This script solves for the normalized pressure wave field of 
% an array of 1-D elements radiating waves through a fluid/fluid 
% interface using the MATLAB function ls_2D_int. Both time delay 
% and apodization laws can be specified for the array to steer 
% it and focus it in the second medium.

clear

% ------------give input parameters ------------------
f = 5;      % frequency (MHz)
d1 = 1.0;   % density gm/cm^3   of first medium
c1= 1480;   % wavespeed (m/sec) of first medium
d2 = 7.9;   % density gm/cm^3   of second medium
c2 = 5900;  % wavespeed (m/sec) of second medium
M =32;      % number of elements
d = 0.25;    % element  length (mm)
g = 0.05;     % gap length (mm)
angt = 0;     % angle of array
ang20 = 30.0;    % steering angle, degrees in second medium
DF = 8;      % focal depth (mm) DF = inf for no focusing
DT0 = 25.4 ;   % distance of array from interface (mm). It must be >0
type ='rect';  % type of amplitude weighting function

% generate 2-D area in second medium for field calculations or replace
% with other specifications for x and z, where z is measured from the
% interface into the second medium and must be >0.
x = linspace(-5, 15, 200);
z = linspace(1,20,200);
[xx,zz]=meshgrid(x,z);

% ------------- end of input parameters --------------------

b = d/2;     % element half length
s = d + g;   % pitch of the array
mat = [ d1 c1 d2 c2]; % material properties

% calculate distances to element centers
for mm = 1:M
    e(mm) = s*((2*mm-1)/2 -M/2);
end

% generate time delays, put in exponential 
% and calculate amplitude weights
td =delay_laws2D_int(M,s,angt, ang20, DT0, DF, c1, c2, 'n');
delay = exp(1i.*2.*pi.*f.*td);
Ct=discrete_windows(M,type);

% generate normalized pressure wave field
p = 0;
for mm = 1:M
p=p + Ct(mm).*delay(mm).*ls_2Dint(b, f, mat, e(mm), angt,DT0,xx, zz, 1);
end

% ------------ outputs -----------------
% generate wave field image from x,z specifications. This must be changed
% if (x,z) input secifications are changed.
imagesc(x, z, abs(p))
xlabel( ' x , mm')
ylabel( ' z , mm')
