% script mls_array_modeling
clear

% give input parameters
f= 5;      % frequency (MHz)
c=1480;    % wavespeed (m/sec)
M =32;     % number of elements
dl =0.5; % element length, d, divided by wave length
gd =0.1;   % gap betweeen elements, g, divided by d
Phi =20.;  % steering angle, degrees
F = inf;     % focal length (mm) F=inf for no focusing
type ='rect';  % type of amplitude weighting function

%calculate size of array, A, element length, d, gap size, g, 
% and location of element centroids, e.
[A, d, g, e] = elements(f, c, dl, gd, M);
b=d/2;
s=d+g;


% generate 2-D area for field calculations
z= linspace(1, 100*dl, 500);
x=linspace(-50*dl,50*dl,500);
[xx,zz]=meshgrid(x,z);

% generate time delays, put in exponential 
% and calculate amplitude weights
td =delay_laws2D(M,s,Phi,F,c);
delay = exp(1i.*2.*pi.*f.*td);
Ct=discrete_windows(M,type);

% generate normalized pressure wave field
p = 0;
for mm = 1:M
p=p + Ct(mm).*delay(mm).*ls_2Dv(b, f, c, e(mm), xx, zz);
end

% generate wave field image
imagesc(x, z, abs(p))
xlabel( ' x , mm')
ylabel( ' z , mm')
