% script mps_array_modeling
% This script solves for the normalized pressure wave field of a 2-D 
% array of rectangular elements radiating waves in a fluid using the
% MATLAB function ps_3Dv. Both time delay and apodization laws can 
% be specified for the array to steer it and focus it.

clear

%  ------------- give input parameters -------------------------
lx = 0.15;   % element length in x-direction (mm)
ly = 0.15;   % element length in y-direction (mm)
gx=0.05;   % gap length in x-direction (mm)
gy = 0.05; % gap length in y-direction (mm)
f= 5;       % frequency (MHz)
c = 1480;   % wave speed (m/sec)
L1 =11;      % number of elements in x-direction
L2 =11;      % number of elements in y-direction
theta =20;   % steering angle in theta direction (deg)
phi =0;     %steering angle in phi direction (deg)
Fl = inf;  % focal distance (mm)
%weighting choices are 'rect','cos', 'Han', 'Ham', 'Blk', 'tri' 
ampx_type ='rect';   % weighting coeffcients in x-direction
ampy_type ='rect';   % weighting coefficients in y-direction

% field points (x,y,z)to evaluate
xs= linspace(-15,15, 300);
zs= linspace(1, 20, 200);
y=0;
[x,z]=meshgrid(xs,zs);

% ---------------- end input parameters ----------------------

% calculate array pitches
sx = lx+gx;
sy = ly+gy;

% compute centroid locations for the elements
Nx = 1:L1;
Ny = 1:L2;
ex =(2*Nx -1-L1)*(sx/2);
ey =(2*Ny -1 -L2)*(sy/2);

% generate time delays, put in exponential 
% and calculate amplitude weights
td =delay_laws3D(L1,L2,sx,sy,theta,phi,Fl,c);
delay = exp(1i.*2.*pi.*f.*td);
Cx = discrete_windows(L1,ampx_type);
Cy = discrete_windows(L2,ampy_type);


% calculate normalized pressure
p=0;
for nn=1:L1
    for ll=1:L2
        p = p + Cx(nn)*Cy(ll)*delay(nn,ll)...
            *ps_3Dv(lx,ly,f,c,ex(nn),ey(ll),x,y,z);
    end
end

% ---------------- outputs --------------------------
%plot results based on specification of (x,y,z) points
imagesc(xs,zs,abs(p))       
        